class JobScoring():
    """Manage job related profile calls."""

    def __init__(self, api):
        """Init."""
        self.client = api

    # TODO add job scoring
    def get(self):
        return
